LoadRequestedModules

Function LoadRequestedModules 

pub unsafe extern "C" fn LoadRequestedModules(
    cx: *mut JSContext,
    module: Handle<*mut JSObject>,
    hostDefined: Handle<Value>,
    resolved: Option<unsafe extern "C" fn(*mut JSContext, Handle<Value>) -> bool>,
    rejected: Option<unsafe extern "C" fn(*mut JSContext, Handle<Value>, Handle<Value>) -> bool>,
) -> bool
https://tc39.es/ecma262/#sec-LoadRequestedModules

Load the dependency module graph of the parameter ‘module’.

The spec defines using ‘promise objects’ to notify the result. To address the synchronous loading behavior from mozJSModuleLoader, an overloaded version that takes function callbacks to notify the result is also provided.