#[repr(C)]pub struct AutoRequireNoGC {
pub _address: u8,
}Expand description
Pass a subclass of this “abstract” class to callees to require that they never GC. Subclasses can use assertions or the hazard analysis to ensure no GC happens.
Fields
_address: u8Trait Implementations
Sourceimpl Debug for AutoRequireNoGC
impl Debug for AutoRequireNoGC
Sourceimpl PartialEq for AutoRequireNoGC
impl PartialEq for AutoRequireNoGC
Sourcefn eq(&self, other: &AutoRequireNoGC) -> bool
fn eq(&self, other: &AutoRequireNoGC) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AutoRequireNoGC