#[repr(C)]pub struct RealmBehaviors {
pub localeOverride_: RefPtr<LocaleString>,
pub timeZoneOverride_: RefPtr<TimeZoneString>,
pub rtpCallerType: __BindgenOpaqueArray<u8, 2>,
pub discardSource_: bool,
pub clampAndJitterTime_: bool,
pub isNonLive_: bool,
}Expand description
RealmBehaviors specifies behaviors of a realm that can be changed after the realm’s been created.
Fields
localeOverride_: RefPtr<LocaleString>timeZoneOverride_: RefPtr<TimeZoneString>rtpCallerType: __BindgenOpaqueArray<u8, 2>discardSource_: boolclampAndJitterTime_: boolisNonLive_: boolTrait Implementations
Sourceimpl Debug for RealmBehaviors
impl Debug for RealmBehaviors
Sourceimpl PartialEq for RealmBehaviors
impl PartialEq for RealmBehaviors
Sourcefn eq(&self, other: &RealmBehaviors) -> bool
fn eq(&self, other: &RealmBehaviors) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RealmBehaviors