RealmCreationOptions

Struct RealmCreationOptions 

#[repr(C)]
pub struct RealmCreationOptions {
Show 13 fields pub traceGlobal_: Option<unsafe extern "C" fn(*mut JSTracer, *mut JSObject)>, pub compSpec_: CompartmentSpecifier, pub __bindgen_anon_1: RealmCreationOptions__bindgen_ty_1, pub profilerRealmID_: u64, pub invisibleToDebugger_: bool, pub preserveJitCode_: bool, pub sharedMemoryAndAtomics_: bool, pub defineSharedArrayBufferConstructor_: bool, pub coopAndCoep_: bool, pub toSource_: bool, pub secureContext_: bool, pub freezeBuiltins_: bool, pub alwaysUseFdlibm_: bool,
}
RealmCreationOptions specifies options relevant to creating a new realm, that are either immutable characteristics of that realm or that are discarded after the realm has been created.

Access to these options on an existing realm is read-only: if you need particular selections, you must make them before you create the realm.

Fields

traceGlobal_: Option<unsafe extern "C" fn(*mut JSTracer, *mut JSObject)>compSpec_: CompartmentSpecifier__bindgen_anon_1: RealmCreationOptions__bindgen_ty_1profilerRealmID_: u64invisibleToDebugger_: boolpreserveJitCode_: boolsharedMemoryAndAtomics_: booldefineSharedArrayBufferConstructor_: boolcoopAndCoep_: booltoSource_: boolsecureContext_: boolfreezeBuiltins_: boolalwaysUseFdlibm_: bool